@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import threading
+import operator
 import unittest
 import time
 import sys
@@ -233,17 +234,17 @@ class TestLuaRuntime(SetupLuaRuntimeMixin, unittest.TestCase):
 
     def test_len_table(self):
         table = self.lua.eval('{1,2,3,4, a=1, b=2, c=3}')
-        self.assertEqual(4, len(table)) # as returned by Lua's "#" operator
+        self.assertEqual(4, len(table))  # as returned by Lua's "#" operator
 
     def test_iter_table(self):
         table = self.lua.eval('{2,3,4,5,6}')
         self.assertEqual([1,2,3,4,5], list(table))
 
-    def test_iter_table_repeat(self):
+    def test_iter_table_list_repeat(self):
         table = self.lua.eval('{2,3,4,5,6}')
-        self.assertEqual([1,2,3,4,5], list(table)) # 1
-        self.assertEqual([1,2,3,4,5], list(table)) # 2
-        self.assertEqual([1,2,3,4,5], list(table)) # 3
+        self.assertEqual([1,2,3,4,5], list(table))  # 1
+        self.assertEqual([1,2,3,4,5], list(table))  # 2
+        self.assertEqual([1,2,3,4,5], list(table))  # 3
 
     def test_iter_array_table_values(self):
         table = self.lua.eval('{2,3,4,5,6}')
@@ -251,30 +252,30 @@ class TestLuaRuntime(SetupLuaRuntimeMixin, unittest.TestCase):
 
     def test_iter_array_table_repeat(self):
         table = self.lua.eval('{2,3,4,5,6}')
-        self.assertEqual([2,3,4,5,6], list(table.values())) # 1
-        self.assertEqual([2,3,4,5,6], list(table.values())) # 2
-        self.assertEqual([2,3,4,5,6], list(table.values())) # 3
+        self.assertEqual([2,3,4,5,6], list(table.values()))  # 1
+        self.assertEqual([2,3,4,5,6], list(table.values()))  # 2
+        self.assertEqual([2,3,4,5,6], list(table.values()))  # 3
 
     def test_iter_multiple_tables(self):
         count = 10
-        table_values = [ self.lua.eval('{%s}' % ','.join(map(str, range(2,count+2)))).values()
-                         for _ in range(4) ]
+        table_values = [self.lua.eval('{%s}' % ','.join(map(str, range(2, count+2)))).values()
+                        for _ in range(4)]
 
         # round robin
-        l = [ [] for _ in range(count) ]
+        l = [[] for _ in range(count)]
         for sublist in l:
             for table in table_values:
                 sublist.append(_next(table))
 
-        self.assertEqual([[i]*len(table_values) for i in range(2,count+2)], l)
+        self.assertEqual([[i]*len(table_values) for i in range(2, count+2)], l)
 
     def test_iter_table_repeat(self):
         count = 10
-        table_values = [ self.lua.eval('{%s}' % ','.join(map(str, range(2,count+2)))).values()
-                         for _ in range(4) ]
+        table_values = [self.lua.eval('{%s}' % ','.join(map(str, range(2, count+2)))).values()
+                        for _ in range(4)]
 
         # one table after the other
-        l = [ [] for _ in range(count) ]
+        l = [[] for _ in range(count)]
         for table in table_values:
             for sublist in l:
                 sublist.append(_next(table))
@@ -296,59 +297,59 @@ class TestLuaRuntime(SetupLuaRuntimeMixin, unittest.TestCase):
 
     def test_iter_table_mapping(self):
         keys = list('abcdefg')
-        table = self.lua.eval('{%s}' % ','.join(['%s=%d' % (c,i) for i,c in enumerate(keys)]))
+        table = self.lua.eval('{%s}' % ','.join('%s=%d' % (c, i) for i, c in enumerate(keys)))
         l = list(table)
         l.sort()
         self.assertEqual(keys, l)
 
     def test_iter_table_mapping_int_keys(self):
-        table = self.lua.eval('{%s}' % ','.join(['[%d]=%d' % (i,-i) for i in range(10) ]))
+        table = self.lua.eval('{%s}' % ','.join('[%d]=%d' % (i, -i) for i in range(10)))
         l = list(table)
         l.sort()
         self.assertEqual(list(range(10)), l)
 
     def test_iter_table_keys(self):
         keys = list('abcdefg')
-        table = self.lua.eval('{%s}' % ','.join(['%s=%d' % (c,i) for i,c in enumerate(keys)]))
+        table = self.lua.eval('{%s}' % ','.join('%s=%d' % (c, i) for i, c in enumerate(keys)))
         l = list(table.keys())
         l.sort()
         self.assertEqual(keys, l)
 
     def test_iter_table_keys_int_keys(self):
-        table = self.lua.eval('{%s}' % ','.join(['[%d]=%d' % (i,-i) for i in range(10) ]))
+        table = self.lua.eval('{%s}' % ','.join('[%d]=%d' % (i, -i) for i in range(10)))
         l = list(table.keys())
         l.sort()
         self.assertEqual(list(range(10)), l)
 
     def test_iter_table_values(self):
         keys = list('abcdefg')
-        table = self.lua.eval('{%s}' % ','.join(['%s=%d' % (c,i) for i,c in enumerate(keys)]))
+        table = self.lua.eval('{%s}' % ','.join('%s=%d' % (c, i) for i, c in enumerate(keys)))
         l = list(table.values())
         l.sort()
         self.assertEqual(list(range(len(keys))), l)
 
     def test_iter_table_values_int_keys(self):
-        table = self.lua.eval('{%s}' % ','.join(['[%d]=%d' % (i,-i) for i in range(10) ]))
+        table = self.lua.eval('{%s}' % ','.join('[%d]=%d' % (i, -i) for i in range(10)))
         l = list(table.values())
         l.sort()
         self.assertEqual(list(range(-9,1)), l)
 
     def test_iter_table_items(self):
         keys = list('abcdefg')
-        table = self.lua.eval('{%s}' % ','.join(['%s=%d' % (c,i) for i,c in enumerate(keys)]))
+        table = self.lua.eval('{%s}' % ','.join('%s=%d' % (c, i) for i, c in enumerate(keys)))
         l = list(table.items())
         l.sort()
         self.assertEqual(list(zip(keys,range(len(keys)))), l)
 
     def test_iter_table_items_int_keys(self):
-        table = self.lua.eval('{%s}' % ','.join(['[%d]=%d' % (i,-i) for i in range(10) ]))
+        table = self.lua.eval('{%s}' % ','.join('[%d]=%d' % (i, -i) for i in range(10)))
         l = list(table.items())
         l.sort()
         self.assertEqual(list(zip(range(10), range(0,-10,-1))), l)
 
     def test_iter_table_values_mixed(self):
         keys = list('abcdefg')
-        table = self.lua.eval('{98, 99; %s}' % ','.join(['%s=%d' % (c,i) for i,c in enumerate(keys)]))
+        table = self.lua.eval('{98, 99; %s}' % ','.join('%s=%d' % (c, i) for i, c in enumerate(keys)))
         l = list(table.values())
         l.sort()
         self.assertEqual(list(range(len(keys))) + [98, 99], l)
@@ -946,6 +947,21 @@ class TestPythonObjectsInLua(SetupLuaRuntimeMixin, unittest.TestCase):
 
 
 class TestLuaCoroutines(SetupLuaRuntimeMixin, unittest.TestCase):
+    def test_coroutine_object(self):
+        f = self.lua.eval("function(N) coroutine.yield(N) end")
+        gen = f.coroutine(5)
+        self.assertRaises(AttributeError, getattr, gen, '__setitem__')
+        self.assertRaises(AttributeError, setattr, gen, 'send', 5)
+        self.assertRaises(AttributeError, setattr, gen, 'no_such_attribute', 5)
+        self.assertRaises(AttributeError, getattr, gen, 'no_such_attribute')
+        self.assertRaises(AttributeError, gen.__getattr__, 'no_such_attribute')
+
+        self.assertRaises(lupa.LuaError, gen.__call__)
+        self.assertTrue(hasattr(gen.send, '__call__'))
+
+        self.assertRaises(TypeError, operator.itemgetter(1), gen)
+        self.assertRaises(TypeError, gen.__getitem__, 1)
+
     def test_coroutine_iter(self):
         lua_code = '''\
             function(N)
@@ -1084,7 +1100,7 @@ class TestLuaCoroutines(SetupLuaRuntimeMixin, unittest.TestCase):
             end
         '''
         count = self.lua.eval(lua_code).coroutine()
-        result = [ count.send(value) for value in ([None]+[True]*9+[False]) ]
+        result = [count.send(value) for value in ([None] + [True] * 9 + [False])]
         self.assertEqual(list(range(10)) + [9], result)
         self.assertRaises(StopIteration, count.send, True)
 
@@ -1099,8 +1115,8 @@ class TestLuaCoroutines(SetupLuaRuntimeMixin, unittest.TestCase):
         count = self.lua.eval(lua_code).coroutine(5)
         result = []
         try:
-            for value in ([None]+list(range(10))):
-                result.append( count.send(value) )
+            for value in ([None] + list(range(10))):
+                result.append(count.send(value))
         except StopIteration:
             pass
         else:
@@ -1898,7 +1914,7 @@ class TestFastRLock(unittest.TestCase):
     (which can be acquired and released from different threads).
     """
 
-    def test_reacquire(self):
+    def DISABLED_test_reacquire_non_recursive(self):
         # Lock needs to be released before re-acquiring.
         lock = self.locktype()
         phase = []
